==> tiki-9.7.tar.bz2: tiki-9.7/lib/wiki-plugins/wikiplugin_favorite.php <==
<?php
// (c) Copyright 2002-2012 by authors of the Tiki Wiki CMS Groupware Project
// 
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: wikiplugin_favorite.php 39469 2012-01-12 21:13:48Z changi67 $

function wikiplugin_favorite_info()
{
	return array(
		'name' => tra('Favorite'),
		'documentation' => 'PluginFavorite',
		'description' => tra('Shows if item is user favorite or not and provide the way to set it'),
		'prefs' => array( 'wikiplugin_favorite', 'user_favorites' ),	
		'format' => 'html',
		'params' => array(
			'objectType' => array(
				'required' => true,
				'name' => tra('Object Type'),
				'description' => tra('Object Type'),
				'filter' => 'text',
				'default' => '',
			),
			'objectId' => array(
				'required' => true,
				'name' => tra('Object ID'),
				'description' => tra('Object ID'),
				'filter' => 'text',
				'default' => '',
			),
		)
	);
}
function wikiplugin_favorite($data, $params)
{
	global $smarty;
	if ($params['objectType'] == 'usertracker') {
		$objectType = 'trackeritem';
		$objectId = 0;
		if ($userid = Tikilib::lib('tiki')->get_user_id($params['objectId'])) {
			$tracker = TikiLib::lib('user')->get_usertracker($userid);
			if ( $tracker && $tracker['usersTrackerId'] ) {
				$objectId = TikiLib::lib('trk')->get_item_id($tracker['usersTrackerId'], $tracker['usersFieldId'], $params['objectId']);
			}
		}
	} else {
		$objectType = $params['objectType'];
		$objectId = $params['objectId'];
	}
	$smarty->assign('wikiplugin_favorite_objectId', urlencode($objectId));
	$smarty->assign('wikiplugin_favorite_objectType', urlencode($objectType));	
	$ret = $smarty->fetch('wiki-plugins/wikiplugin_favorite.tpl');
	return $ret;
}

==> tiki-19.1.tar.bz2: tiki-19.1/lib/wiki-plugins/wikiplugin_favorite.php <==
<?php
// (c) Copyright by authors of the Tiki Wiki CMS Groupware Project
//
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: wikiplugin_favorite.php 66111 2018-04-19 18:24:55Z luciash $

function wikiplugin_favorite_info()
{
	return [
		'name' => tra('Favorite'),
		'documentation' => 'PluginFavorite',
		'description' => tra('Display a button for a user to click to make an object a favorite'),
		'prefs' => [ 'wikiplugin_favorite', 'user_favorites' ],
		'format' => 'html',
		'iconname' => 'star',
		'introduced' => 8,
		'params' => [
			'objectType' => [
				'required' => true,
				'name' => tra('Object Type'),
				'description' => tra('Indicate type of object'),
				'since' => '8.0',
				'filter' => 'text',
				'default' => '',
			],
			'objectId' => [
				'required' => true,
				'name' => tra('Object ID'),
				'description' => tra('Enter the ID of the object'),
				'since' => '8.0',
				'filter' => 'text',
				'default' => '',
				'profile_reference' => 'type_in_param',
			],
		]
	];
}
function wikiplugin_favorite($data, $params)
{
	$smarty = TikiLib::lib('smarty');
	if ($params['objectType'] == 'usertracker') {
		$objectType = 'trackeritem';
		$objectId = 0;
		if ($userid = TikiLib::lib('tiki')->get_user_id($params['objectId'])) {
			$tracker = TikiLib::lib('user')->get_usertracker($userid);
			if ($tracker && $tracker['usersTrackerId']) {
				$objectId = TikiLib::lib('trk')->get_item_id($tracker['usersTrackerId'], $tracker['usersFieldId'], $params['objectId']);
			}
		}
	} else {
		$objectType = $params['objectType'];
		$objectId = $params['objectId'];
	}
	$smarty->assign('wikiplugin_favorite_objectId', urlencode($objectId));
	$smarty->assign('wikiplugin_favorite_objectType', urlencode($objectType));
	$ret = $smarty->fetch('wiki-plugins/wikiplugin_favorite.tpl');
	return $ret;
}
